@@ -123,7 +123,7 @@ class MediaShowListingView(BrowserView):
         if hasattr(self.request, 'recursive'):
             recursive = self.request['recursive']
         else:
-            recursive = "true"
+            recursive = "false"
         
         recursiveMode = False
         
@@ -170,17 +170,6 @@ class MediaShowListingView(BrowserView):
                 resultArray.append({"url": res.getURL(), "UID": res["UID"]})
 
         jsonStr = json.dumps(resultArray[:100])
-            
-        #Manual encoding 
-        #jsonStr = "["
-        #for res in results:
-        #    if(self.getMediaURL(res.getObject()) != ""):
-        #        jsonStr += '{"url" : "'+res.getURL()+'", "UID" : "'+res["UID"]+'"}'
-        #        jsonStr += ","
-        #    
-        #if jsonStr != "[":
-        #    jsonStr = jsonStr[:-1]
-        #jsonStr += "]"
         
         if callback is not None:
             return callback +'(' + jsonStr + ')'
@@ -191,19 +180,6 @@ class MediaShowListingView(BrowserView):
     def getMediaURL(self, item):
         """ finds and returns relevant leading media for the given item
         """
-        #--- Checking for recursive mode
-        if hasattr(self.request, 'recursive'):
-            recursive = self.request['recursive']
-        else:
-            recursive = "true"
-        
-        recursiveMode = False
-        
-        if recursive.find("true") != -1:
-            recursiveMode = True
-        
-        #---
-        
         if(self.isVideo(item)):
             return item.absolute_url()
             
@@ -213,7 +189,25 @@ class MediaShowListingView(BrowserView):
         if item.portal_type == 'Image':
             return item.absolute_url()
         
-        return ""
+        catalog = getToolByName(self.context, 'portal_catalog')
+        plone_utils = getToolByName(self.context, 'plone_utils')
+        path = '/'.join(item.getPhysicalPath())
+        
+        if plone_utils.isStructuralFolder(item):
+            results = catalog.searchResults(path = {'query' : path,'depth' : 1 }, type = ['Image', 'File', 'Link'], sort_on = 'getObjPositionInParent')
+            if len(results) > 0:
+                leadMedia = results[0]
+                if leadMedia.portal_type == 'Image':
+                    return leadMedia.getURL() + '/image_large'
+                elif leadMedia.portal_type == 'Link':
+                    return leadMedia.remoteUrl
+                else:
+                    return leadMedia.getURL()
+            else:
+                return ""
+        else:
+            #TODO: Add lead image support and News Item Image support
+            return ""
         
     def isVideo(self, item):
         if FLOWPLAYER_EXISTS:
